@@ -22,12 +22,12 @@ sub start {
 
 after add_target_endpoint => sub {
   my ($self, $alias, $target) = @_;
-  $self->emit( 'connected_to', $target );
+  $self->emit_now( 'connected_to', $target );
 };
 
 sub stop {
   my ($self) = @_;
-  $self->emit( 'stopped' );
+  $self->emit_now( 'stopped' );
   $self->clear_zmq_socket( ZALIAS );
   $self->_stop_emitter;
 }
